# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if getattr(kaitaistruct, 'API_VERSION', (0, 9)) < (0, 9):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Cute(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field ccsds_version: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.ccsds_version
    :field packet_type: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.packet_type
    :field secondary_header_flag: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.secondary_header_flag
    :field is_stored_data: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.is_stored_data
    :field application_process_id: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.application_process_id
    :field grouping_flag: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.grouping_flag
    :field sequence_count: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.sequence_count
    :field packet_length: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.packet_length
    :field time_stamp_seconds: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.secondary_header.time_stamp_seconds
    :field sub_seconds: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.secondary_header.sub_seconds
    :field padding: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.secondary_header.padding
    :field soh_l0_wdt_2sec_cnt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.wdt_2sec_cnt
    :field soh_l0_reset_armed: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.reset_armed
    :field soh_l0_wdt_stat: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.wdt_stat
    :field soh_l0_wdt_en: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.wdt_en
    :field soh_l0_table_select: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.table_select
    :field soh_l0_boot_relay: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.boot_relay
    :field soh_l0_l0_acpt_cnt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.l0_acpt_cnt
    :field soh_l0_l0_rjct_cnt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.l0_rjct_cnt
    :field soh_l0_hw_sec_cnt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.hw_sec_cnt
    :field soh_l0_time_tag: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.time_tag
    :field soh_l0_pld_tlm_ack_cnt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.pld_tlm_ack_cnt
    :field soh_l0_pld_cmd_cnt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.pld_cmd_cnt
    :field soh_l0_pld_tlm_to_cnt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.pld_tlm_to_cnt
    :field soh_l0_pld_tlm_nak_cnt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.pld_tlm_nak_cnt
    :field soh_l0_spare_end: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_l0.spare_end
    :field soh_command_tlm_cmd_status: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.cmd_status
    :field soh_command_tlm_realtime_cmd_accept_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.realtime_cmd_accept_count
    :field soh_command_tlm_realtime_cmd_reject_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.realtime_cmd_reject_count
    :field soh_command_tlm_stored_cmd_accept_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.stored_cmd_accept_count
    :field soh_command_tlm_stored_cmd_reject_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.stored_cmd_reject_count
    :field soh_command_tlm_macros_executing_pack1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack1
    :field soh_command_tlm_macros_executing_pack_bit8: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit8
    :field soh_command_tlm_macros_executing_pack_bit7: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit7
    :field soh_command_tlm_macros_executing_pack_bit6: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit6
    :field soh_command_tlm_macros_executing_pack_bit5: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit5
    :field soh_command_tlm_macros_executing_pack_bit4: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit4
    :field soh_command_tlm_macros_executing_pack_bit3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit3
    :field soh_command_tlm_macros_executing_pack_bit2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit2
    :field soh_command_tlm_macros_executing_pack_bit1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit1
    :field soh_command_tlm_macros_executing_pack2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack2
    :field soh_command_tlm_macros_executing_pack_bit16: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit16
    :field soh_command_tlm_macros_executing_pack_bit15: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit15
    :field soh_command_tlm_macros_executing_pack_bit14: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit14
    :field soh_command_tlm_macros_executing_pack_bit13: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit13
    :field soh_command_tlm_macros_executing_pack_bit12: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit12
    :field soh_command_tlm_macros_executing_pack_bit11: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit11
    :field soh_command_tlm_macros_executing_pack_bit10: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit10
    :field soh_command_tlm_macros_executing_pack_bit9: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_command_tlm.macros_executing_pack_bit9
    :field soh_general_scrub_status_overall: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_general.scrub_status_overall
    :field soh_general_image_booted: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_general.image_booted
    :field soh_general_image_auto_failover: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_general.image_auto_failover
    :field soh_time_tai_seconds: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_time.tai_seconds
    :field soh_time_time_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_time.time_valid
    :field soh_refs_position_wrt_eci1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_refs.position_wrt_eci1
    :field soh_refs_position_wrt_eci2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_refs.position_wrt_eci2
    :field soh_refs_position_wrt_eci3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_refs.position_wrt_eci3
    :field soh_refs_velocity_wrt_eci1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_refs.velocity_wrt_eci1
    :field soh_refs_velocity_wrt_eci2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_refs.velocity_wrt_eci2
    :field soh_refs_velocity_wrt_eci3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_refs.velocity_wrt_eci3
    :field soh_refs_refs_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_refs.refs_valid
    :field soh_att_det_q_body_wrt_eci1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.q_body_wrt_eci1
    :field soh_att_det_q_body_wrt_eci2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.q_body_wrt_eci2
    :field soh_att_det_q_body_wrt_eci3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.q_body_wrt_eci3
    :field soh_att_det_q_body_wrt_eci4: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.q_body_wrt_eci4
    :field soh_att_det_body_rate1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.body_rate1
    :field soh_att_det_body_rate1_dps: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.body_rate1_dps
    :field soh_att_det_body_rate1_rpm: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.body_rate1_rpm
    :field soh_att_det_body_rate2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.body_rate2
    :field soh_att_det_body_rate2_dps: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.body_rate2_dps
    :field soh_att_det_body_rate2_rpm: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.body_rate2_rpm
    :field soh_att_det_body_rate3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.body_rate3
    :field soh_att_det_body_rate3_dps: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.body_rate3_dps
    :field soh_att_det_body_rate3_rpm: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.body_rate3_rpm
    :field soh_att_det_bad_att_timer: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.bad_att_timer
    :field soh_att_det_bad_rate_timer: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.bad_rate_timer
    :field soh_att_det_reinit_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.reinit_count
    :field soh_att_det_attitude_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.attitude_valid
    :field soh_att_det_meas_att_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.meas_att_valid
    :field soh_att_det_meas_rate_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.meas_rate_valid
    :field soh_att_det_tracker_used: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_det.tracker_used
    :field soh_att_cmd_hr_cycle_safe_mode: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_cmd.hr_cycle_safe_mode
    :field soh_att_cmd_rotisserie_rate: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_cmd.rotisserie_rate
    :field soh_att_cmd_rotisserie_rate_dps: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_cmd.rotisserie_rate_dps
    :field soh_att_cmd_rotisserie_rate_rpm: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_cmd.rotisserie_rate_rpm
    :field soh_att_cmd_adcs_mode: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_cmd.adcs_mode
    :field soh_att_cmd_safe_mode_reason: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_cmd.safe_mode_reason
    :field soh_att_cmd_recommend_sun_point: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_cmd.recommend_sun_point
    :field soh_rw_drive_filtered_speed_rpm1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_rw_drive.filtered_speed_rpm1
    :field soh_rw_drive_filtered_speed_rpm2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_rw_drive.filtered_speed_rpm2
    :field soh_rw_drive_filtered_speed_rpm3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_rw_drive.filtered_speed_rpm3
    :field soh_tracker_operating_mode: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker.operating_mode
    :field soh_tracker_star_id_step: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker.star_id_step
    :field soh_tracker_att_status: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker.att_status
    :field soh_tracker_num_attitude_stars: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker.num_attitude_stars
    :field soh_att_ctrl_position_error1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_ctrl.position_error1
    :field soh_att_ctrl_position_error2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_ctrl.position_error2
    :field soh_att_ctrl_position_error3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_ctrl.position_error3
    :field soh_att_ctrl_time_into_search: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_ctrl.time_into_search
    :field soh_att_ctrl_wait_timer: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_ctrl.wait_timer
    :field soh_att_ctrl_sun_point_angle_error: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_ctrl.sun_point_angle_error
    :field soh_att_ctrl_sun_point_state: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_att_ctrl.sun_point_state
    :field soh_momentum_momentum_vector_body1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.momentum_vector_body1
    :field soh_momentum_momentum_vector_body2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.momentum_vector_body2
    :field soh_momentum_momentum_vector_body3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.momentum_vector_body3
    :field soh_momentum_duty_cycle1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.duty_cycle1
    :field soh_momentum_duty_cycle2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.duty_cycle2
    :field soh_momentum_duty_cycle3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.duty_cycle3
    :field soh_momentum_torque_rod_mode1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.torque_rod_mode1
    :field soh_momentum_torque_rod_mode2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.torque_rod_mode2
    :field soh_momentum_torque_rod_mode3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.torque_rod_mode3
    :field soh_momentum_mag_source_used: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.mag_source_used
    :field soh_momentum_momentum_vector_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_momentum.momentum_vector_valid
    :field soh_css_sun_vector_body1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_css.sun_vector_body1
    :field soh_css_sun_vector_body2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_css.sun_vector_body2
    :field soh_css_sun_vector_body3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_css.sun_vector_body3
    :field soh_css_sun_vector_status: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_css.sun_vector_status
    :field soh_css_sun_sensor_used: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_css.sun_sensor_used
    :field soh_mag_mag_vector_body1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_mag.mag_vector_body1
    :field soh_mag_mag_vector_body2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_mag.mag_vector_body2
    :field soh_mag_mag_vector_body3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_mag.mag_vector_body3
    :field soh_mag_mag_vector_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_mag.mag_vector_valid
    :field soh_imu_new_packet_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_imu.new_packet_count
    :field soh_imu_imu_vector_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_imu.imu_vector_valid
    :field soh_clock_sync_hr_run_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_clock_sync.hr_run_count
    :field soh_clock_sync_hr_exec_time_ms: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_clock_sync.hr_exec_time_ms
    :field soh_analogs_box1_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_analogs.box1_temp
    :field soh_analogs_bus_voltage: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_analogs.bus_voltage
    :field soh_analogs_battery_voltage: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_analogs.battery_voltage
    :field soh_analogs_battery_current: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_analogs.battery_current
    :field soh_tracker2_operating_mode: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker2.operating_mode
    :field soh_tracker2_star_id_step: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker2.star_id_step
    :field soh_tracker2_att_status: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker2.att_status
    :field soh_tracker2_num_attitude_stars: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker2.num_attitude_stars
    :field soh_gps_gps_lock_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_gps.gps_lock_count
    :field soh_gps_gps_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_gps.gps_valid
    :field soh_gps_gps_enable: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_gps.gps_enable
    :field soh_event_check_latched_resp_fire_pack1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack1
    :field soh_event_check_latched_resp_fire_pack_bit8: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit8
    :field soh_event_check_latched_resp_fire_pack_bit7: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit7
    :field soh_event_check_latched_resp_fire_pack_bit6: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit6
    :field soh_event_check_latched_resp_fire_pack_bit5: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit5
    :field soh_event_check_latched_resp_fire_pack_bit4: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit4
    :field soh_event_check_latched_resp_fire_pack_bit3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit3
    :field soh_event_check_latched_resp_fire_pack_bit2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit2
    :field soh_event_check_latched_resp_fire_pack_bit1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit1
    :field soh_event_check_latched_resp_fire_pack2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack2
    :field soh_event_check_latched_resp_fire_pack_bit16: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit16
    :field soh_event_check_latched_resp_fire_pack_bit15: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit15
    :field soh_event_check_latched_resp_fire_pack_bit14: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit14
    :field soh_event_check_latched_resp_fire_pack_bit13: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit13
    :field soh_event_check_latched_resp_fire_pack_bit12: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit12
    :field soh_event_check_latched_resp_fire_pack_bit11: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit11
    :field soh_event_check_latched_resp_fire_pack_bit10: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit10
    :field soh_event_check_latched_resp_fire_pack_bit9: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_event_check.latched_resp_fire_pack_bit9
    :field soh_radio_sd_minute_cur: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sd_minute_cur
    :field soh_radio_sd_percent_used_total: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sd_percent_used_total
    :field soh_radio_sd_ok: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sd_ok
    :field soh_radio_sd_fault_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sd_fault_count
    :field soh_radio_sdr_tx_tx_frames: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sdr_tx_tx_frames
    :field soh_radio_sdr_tx_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sdr_tx_temp
    :field soh_radio_sdr_tx_comm_error: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sdr_tx_comm_error
    :field soh_radio_sq_channel: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sq_channel
    :field soh_radio_sq_trap_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sq_trap_count
    :field soh_radio_sq_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_radio.sq_temp
    :field soh_tracker_ctrl_aid_status1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status1
    :field soh_tracker_ctrl_aid_status_bit8: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit8
    :field soh_tracker_ctrl_aid_status_bit7: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit7
    :field soh_tracker_ctrl_aid_status_bit6: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit6
    :field soh_tracker_ctrl_aid_status_bit5: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit5
    :field soh_tracker_ctrl_aid_status_bit4: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit4
    :field soh_tracker_ctrl_aid_status_bit3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit3
    :field soh_tracker_ctrl_aid_status_bit2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit2
    :field soh_tracker_ctrl_aid_status_bit1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit1
    :field soh_tracker_ctrl_aid_status2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status2
    :field soh_tracker_ctrl_aid_status_bit16: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit16
    :field soh_tracker_ctrl_aid_status_bit15: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit15
    :field soh_tracker_ctrl_aid_status_bit14: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit14
    :field soh_tracker_ctrl_aid_status_bit13: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit13
    :field soh_tracker_ctrl_aid_status_bit12: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit12
    :field soh_tracker_ctrl_aid_status_bit11: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit11
    :field soh_tracker_ctrl_aid_status_bit10: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit10
    :field soh_tracker_ctrl_aid_status_bit9: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.aid_status_bit9
    :field soh_tracker_ctrl_star_id_status: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.soh_tracker_ctrl.star_id_status
    :field pld_pkt_ccsds_version: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.ccsds_version
    :field pld_pkt_packet_type: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.packet_type
    :field pld_pkt_secondary_header_flag: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.secondary_header_flag
    :field pld_pkt_application_process_id: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.application_process_id
    :field pld_pkt_sequence_flags: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sequence_flags
    :field pld_pkt_sequence_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sequence_count
    :field pld_pkt_packet_length: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.packet_length
    :field pld_sw_stat_sh_coarse: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.sh_coarse
    :field pld_sw_stat_sh_fine: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.sh_fine
    :field pld_sw_stat_pld_sw_ver_maj: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.pld_sw_ver_maj
    :field pld_sw_stat_pld_sw_ver_min: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.pld_sw_ver_min
    :field pld_sw_stat_pld_sw_ver_patch: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.pld_sw_ver_patch
    :field pld_sw_stat_spare: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.spare
    :field pld_sw_stat_sd_state_card1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.sd_state_card1
    :field pld_sw_stat_sd_state_card0: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.sd_state_card0
    :field pld_sw_stat_zynq_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.zynq_temp
    :field pld_sw_stat_zynq_vcc_int: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.zynq_vcc_int
    :field pld_sw_stat_zynq_vcc_aux: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.zynq_vcc_aux
    :field pld_sw_stat_zynq_vcc_bram: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.zynq_vcc_bram
    :field pld_sw_stat_zynq_vcc_pint: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.zynq_vcc_pint
    :field pld_sw_stat_zynq_vcc_paux: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.zynq_vcc_paux
    :field pld_sw_stat_zynq_vcc_pdr0: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.zynq_vcc_pdr0
    :field pld_sw_stat_zynq_status: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.zynq_status
    :field pld_sw_stat_spare8: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.spare8
    :field pld_sw_stat_roc_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.roc_temp
    :field pld_sw_stat_ccd_p5: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.ccd_p5
    :field pld_sw_stat_ccd_p15: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.ccd_p15
    :field pld_sw_stat_ccd_p32: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.ccd_p32
    :field pld_sw_stat_ccd_n5: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.ccd_n5
    :field pld_sw_stat_spare16: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.spare16
    :field pld_sw_stat_cmd_recv_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.cmd_recv_count
    :field pld_sw_stat_cmd_rjct_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.cmd_rjct_count
    :field pld_sw_stat_cmd_succ_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.cmd_succ_count
    :field pld_sw_stat_cmd_succ_op: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.cmd_succ_op
    :field pld_sw_stat_cmd_rjct_op: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.cmd_rjct_op
    :field pld_sw_stat_cmd_fail_code: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.cmd_fail_code
    :field pld_sw_stat_spare6: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.spare6
    :field pld_sw_stat_arm_state_sc: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.arm_state_sc
    :field pld_sw_stat_arm_state_dbg: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.arm_state_dbg
    :field pld_sw_stat_log_write_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.log_write_count
    :field pld_sw_stat_log_drop_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.log_drop_count
    :field pld_sw_stat_ccd_ena_state: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.ccd_ena_state
    :field pld_sw_stat_ccd_ctrl_state: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.ccd_ctrl_state
    :field pld_sw_stat_ccd_shutter: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.ccd_shutter
    :field pld_sw_stat_shutter_override: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.shutter_override
    :field pld_sw_stat_frame_id: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.frame_id
    :field pld_sw_stat_os_cpu_usage: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.os_cpu_usage
    :field pld_sw_stat_os_cpu_max: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.os_cpu_max
    :field pld_sw_stat_time_pps_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.time_pps_count
    :field pld_sw_stat_time_recv_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.time_recv_count
    :field pld_sw_stat_time_miss_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.time_miss_count
    :field pld_sw_stat_fsw_mode: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.fsw_mode
    :field pld_sw_stat_tec_state: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_state
    :field pld_sw_stat_tec_slew_rate: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_slew_rate
    :field pld_sw_stat_tec_setpoint: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_setpoint
    :field pld_sw_stat_tec_ccd_rtd: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_ccd_rtd
    :field pld_sw_stat_tec_sc_rtd5: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_sc_rtd5
    :field pld_sw_stat_tec_sc_rtd4: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_sc_rtd4
    :field pld_sw_stat_tec_sc_rtd3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_sc_rtd3
    :field pld_sw_stat_tec_sc_rtd2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_sc_rtd2
    :field pld_sw_stat_tec_sc_rtd1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_sc_rtd1
    :field pld_sw_stat_tec_shutter: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_shutter
    :field pld_sw_stat_tec_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_volt
    :field pld_sw_stat_tec_avg_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_avg_curr
    :field pld_sw_stat_tec_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.tec_curr
    :field pld_sw_stat_img_state: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.img_state
    :field pld_sw_stat_img_curr_proc_type: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.user_data_field.img_curr_proc_type
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Cute.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Cute.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = Cute.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = Cute.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = Cute.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = Cute.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = Cute.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = Cute.IFrame(self._io, self, self._root)


    class CuteBctSohT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.soh_l0 = Cute.SohL0T(self._io, self, self._root)
            self.soh_command_tlm = Cute.SohCommandTlmT(self._io, self, self._root)
            self.soh_general = Cute.SohGeneralT(self._io, self, self._root)
            self.soh_time = Cute.SohTimeT(self._io, self, self._root)
            self.soh_refs = Cute.SohRefsT(self._io, self, self._root)
            self.soh_att_det = Cute.SohAttDetT(self._io, self, self._root)
            self.soh_att_cmd = Cute.SohAttCmdT(self._io, self, self._root)
            self.soh_rw_drive = Cute.SohRwDriveT(self._io, self, self._root)
            self.soh_tracker = Cute.SohTrackerT(self._io, self, self._root)
            self.soh_att_ctrl = Cute.SohAttCtrlT(self._io, self, self._root)
            self.soh_momentum = Cute.SohMomentumT(self._io, self, self._root)
            self.soh_css = Cute.SohCssT(self._io, self, self._root)
            self.soh_mag = Cute.SohMagT(self._io, self, self._root)
            self.soh_imu = Cute.SohImuT(self._io, self, self._root)
            self.soh_clock_sync = Cute.SohClockSyncT(self._io, self, self._root)
            self.soh_analogs = Cute.SohAnalogsT(self._io, self, self._root)
            self.soh_tracker2 = Cute.SohTracker2T(self._io, self, self._root)
            self.soh_gps = Cute.SohGpsT(self._io, self, self._root)
            self.soh_event_check = Cute.SohEventCheckT(self._io, self, self._root)
            self.soh_radio = Cute.SohRadioT(self._io, self, self._root)
            self.soh_tracker_ctrl = Cute.SohTrackerCtrlT(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Cute.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Cute.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Cute.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Cute.SsidMask(self._io, self, self._root)
            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes_full()
            _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = Cute.Ax25InfoData(_io__raw_ax25_info, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")
            if not  ((self.callsign == u"CUTE  ") or (self.callsign == u"BCT   ")) :
                raise kaitaistruct.ValidationNotAnyOfError(self.callsign, self._io, u"/types/callsign/seq/0")


    class SohClockSyncT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.hr_run_count = self._io.read_u4be()
            self.hr_exec_time_ms = self._io.read_u1()


    class SohAttCmdT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.hr_cycle_safe_mode = self._io.read_u4be()
            self.rotisserie_rate = self._io.read_s2be()
            self.adcs_mode = self._io.read_u1()
            self.safe_mode_reason = self._io.read_u1()
            self.recommend_sun_point = self._io.read_u1()


    class SohTrackerCtrlT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.aid_status1 = self._io.read_u1()
            self.aid_status2 = self._io.read_u1()
            self.star_id_status = self._io.read_u1()


    class SohTimeT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.tai_seconds = self._io.read_u4be()
            self.time_valid = self._io.read_u1()


    class SohGpsT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.gps_lock_count = self._io.read_u2be()
            self.gps_valid = self._io.read_u1()
            self.gps_enable = self._io.read_u1()


    class SohRwDriveT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.filtered_speed_rpm1 = self._io.read_s2be()
            self.filtered_speed_rpm2 = self._io.read_s2be()
            self.filtered_speed_rpm3 = self._io.read_s2be()


    class CutePldSwStatT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sh_coarse = self._io.read_u4be()
            self.sh_fine = self._io.read_u2be()
            self.pld_sw_ver_maj = self._io.read_u1()
            self.pld_sw_ver_min = self._io.read_u1()
            self.pld_sw_ver_patch = self._io.read_u1()
            self.spare = self._io.read_bits_int_be(6)
            self.sd_state_card1 = self._io.read_bits_int_be(1) != 0
            self.sd_state_card0 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.zynq_temp = self._io.read_u2be()
            self.zynq_vcc_int = self._io.read_u2be()
            self.zynq_vcc_aux = self._io.read_u2be()
            self.zynq_vcc_bram = self._io.read_u2be()
            self.zynq_vcc_pint = self._io.read_u2be()
            self.zynq_vcc_paux = self._io.read_u2be()
            self.zynq_vcc_pdr0 = self._io.read_u2be()
            self.zynq_status = self._io.read_u1()
            self.spare8 = self._io.read_u1()
            self.proc_temp = self._io.read_s2be()
            self.ccd_p5 = self._io.read_u2be()
            self.ccd_p15 = self._io.read_u2be()
            self.ccd_p32 = self._io.read_u2be()
            self.ccd_n5 = self._io.read_u2be()
            self.spare16 = self._io.read_u2be()
            self.cmd_recv_count = self._io.read_u2be()
            self.cmd_rjct_count = self._io.read_u2be()
            self.cmd_succ_count = self._io.read_u2be()
            self.cmd_succ_op = self._io.read_u2be()
            self.cmd_rjct_op = self._io.read_u2be()
            self.cmd_fail_code = self._io.read_u1()
            self.spare6 = self._io.read_bits_int_be(6)
            self.arm_state_sc = self._io.read_bits_int_be(1) != 0
            self.arm_state_dbg = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.log_write_count = self._io.read_u2be()
            self.log_drop_count = self._io.read_u2be()
            self.ccd_ena_state = self._io.read_u1()
            self.ccd_ctrl_state = self._io.read_u1()
            self.ccd_shutter = self._io.read_u1()
            self.shutter_override = self._io.read_u1()
            self.frame_id = self._io.read_u4be()
            self.os_cpu_usage = self._io.read_u2be()
            self.os_cpu_max = self._io.read_u2be()
            self.time_pps_count = self._io.read_u2be()
            self.time_recv_count = self._io.read_u2be()
            self.time_miss_count = self._io.read_u2be()
            self.fsw_mode = self._io.read_u1()
            self.tec_state = self._io.read_u1()
            self.tec_slew_rate = self._io.read_f4be()
            self.tec_setpoint = self._io.read_f4be()
            self.tec_ccd_rtd = self._io.read_u2be()
            self.tec_sc_rtd5 = self._io.read_u2be()
            self.tec_sc_rtd4 = self._io.read_u2be()
            self.tec_sc_rtd3 = self._io.read_u2be()
            self.tec_sc_rtd2 = self._io.read_u2be()
            self.tec_sc_rtd1 = self._io.read_u2be()
            self.tec_shutter = self._io.read_u2be()
            self.tec_volt = self._io.read_u2be()
            self.tec_avg_curr = self._io.read_u2be()
            self.tec_curr = self._io.read_u2be()
            self.img_state = self._io.read_u1()
            self.img_curr_proc_type = self._io.read_u1()


    class SohAnalogsT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.box1_temp = self._io.read_s2be()
            self.bus_voltage = self._io.read_s2be()
            self.battery_voltage = self._io.read_u2be()
            self.battery_current = self._io.read_s2be()


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes_full()
            _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = Cute.Ax25InfoData(_io__raw_ax25_info, self, self._root)


    class SohRadioT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sd_minute_cur = self._io.read_u4be()
            self.sd_percent_used_total = self._io.read_u1()
            self.sd_ok = self._io.read_u1()
            self.sd_fault_count = self._io.read_u1()
            self.sdr_tx_tx_frames = self._io.read_u4be()
            self.sdr_tx_temp = self._io.read_s1()
            self.sdr_tx_comm_error = self._io.read_u1()
            self.sq_channel = self._io.read_s1()
            self.sq_trap_count = self._io.read_u1()
            self.sq_temp = self._io.read_u1()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return getattr(self, '_m_ssid', None)


    class SohTrackerT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.operating_mode = self._io.read_u1()
            self.star_id_step = self._io.read_u1()
            self.att_status = self._io.read_u1()
            self.num_attitude_stars = self._io.read_u1()


    class SohImuT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.new_packet_count = self._io.read_u1()
            self.imu_vector_valid = self._io.read_u1()


    class DataSectionT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            if self._parent.packet_primary_header.secondary_header_flag:
                self._raw_secondary_header = self._io.read_bytes(6)
                _io__raw_secondary_header = KaitaiStream(BytesIO(self._raw_secondary_header))
                self.secondary_header = Cute.SecondaryHeaderT(_io__raw_secondary_header, self, self._root)

            _on = self._parent.packet_primary_header.application_process_id
            if _on == 86:
                self.user_data_field = Cute.CuteBctSohT(self._io, self, self._root)
            elif _on == 511:
                self.user_data_field = Cute.PldPacketPrimaryHeaderT(self._io, self, self._root)


    class SohMomentumT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.momentum_vector_body1 = self._io.read_s2be()
            self.momentum_vector_body2 = self._io.read_s2be()
            self.momentum_vector_body3 = self._io.read_s2be()
            self.duty_cycle1 = self._io.read_s1()
            self.duty_cycle2 = self._io.read_s1()
            self.duty_cycle3 = self._io.read_s1()
            self.torque_rod_mode1 = self._io.read_u1()
            self.torque_rod_mode2 = self._io.read_u1()
            self.torque_rod_mode3 = self._io.read_u1()
            self.mag_source_used = self._io.read_u1()
            self.momentum_vector_valid = self._io.read_u1()


    class SohCssT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sun_vector_body1 = self._io.read_s2be()
            self.sun_vector_body2 = self._io.read_s2be()
            self.sun_vector_body3 = self._io.read_s2be()
            self.sun_vector_status = self._io.read_u1()
            self.sun_sensor_used = self._io.read_u1()


    class PldPacketPrimaryHeaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ccsds_version = self._io.read_bits_int_be(3)
            self.packet_type = self._io.read_bits_int_be(1) != 0
            self.secondary_header_flag = self._io.read_bits_int_be(1) != 0
            self.application_process_id = self._io.read_bits_int_be(11)
            self.sequence_flags = self._io.read_bits_int_be(2)
            self.sequence_count = self._io.read_bits_int_be(14)
            self._io.align_to_byte()
            self.packet_length = self._io.read_u2be()
            _on = self.application_process_id
            if _on == 1:
                self.user_data_field = Cute.CutePldSwStatT(self._io, self, self._root)


    class SecondaryHeaderT(KaitaiStruct):
        """The Secondary Header is a feature of the Space Packet which allows
        additional types of information that may be useful to the user
        application (e.g., a time code) to be included.
        See: 4.1.3.2 in CCSDS 133.0-B-1
        """
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.time_stamp_seconds = self._io.read_u4be()
            self.sub_seconds = self._io.read_u1()
            self.padding = self._io.read_u1()


    class SohEventCheckT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.latched_resp_fire_pack1 = self._io.read_u1()
            self.latched_resp_fire_pack2 = self._io.read_u1()


    class SohTracker2T(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.operating_mode = self._io.read_u1()
            self.star_id_step = self._io.read_u1()
            self.att_status = self._io.read_u1()
            self.num_attitude_stars = self._io.read_u1()


    class SohMagT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.mag_vector_body1 = self._io.read_s2be()
            self.mag_vector_body2 = self._io.read_s2be()
            self.mag_vector_body3 = self._io.read_s2be()
            self.mag_vector_valid = self._io.read_u1()


    class PacketPrimaryHeaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ccsds_version = self._io.read_bits_int_be(3)
            self.packet_type = self._io.read_bits_int_be(1) != 0
            self.secondary_header_flag = self._io.read_bits_int_be(1) != 0
            self.is_stored_data = self._io.read_bits_int_be(1) != 0
            self.application_process_id = self._io.read_bits_int_be(10)
            self.grouping_flag = self._io.read_bits_int_be(2)
            self.sequence_count = self._io.read_bits_int_be(14)
            self._io.align_to_byte()
            self.packet_length = self._io.read_u2be()


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Cute.Callsign(_io__raw_callsign_ror, self, self._root)


    class SohGeneralT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.scrub_status_overall = self._io.read_s1()
            self.image_booted = self._io.read_u1()
            self.image_auto_failover = self._io.read_u1()


    class SohAttCtrlT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.position_error1 = self._io.read_s4be()
            self.position_error2 = self._io.read_s4be()
            self.position_error3 = self._io.read_s4be()
            self.time_into_search = self._io.read_u2be()
            self.wait_timer = self._io.read_u2be()
            self.sun_point_angle_error = self._io.read_u2be()
            self.sun_point_state = self._io.read_u1()


    class CcsdsSpacePacketT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw_packet_primary_header = self._io.read_bytes(6)
            _io__raw_packet_primary_header = KaitaiStream(BytesIO(self._raw_packet_primary_header))
            self.packet_primary_header = Cute.PacketPrimaryHeaderT(_io__raw_packet_primary_header, self, self._root)
            self.data_section = Cute.DataSectionT(self._io, self, self._root)


    class SohL0T(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.wdt_2sec_cnt = self._io.read_bits_int_be(3)
            self.reset_armed = self._io.read_bits_int_be(1) != 0
            self.wdt_stat = self._io.read_bits_int_be(1) != 0
            self.wdt_en = self._io.read_bits_int_be(1) != 0
            self.table_select = self._io.read_bits_int_be(1) != 0
            self.boot_relay = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.l0_acpt_cnt = self._io.read_u1()
            self.l0_rjct_cnt = self._io.read_u1()
            self.hw_sec_cnt = self._io.read_u1()
            self.padding_0 = self._io.read_u8be()
            self.time_tag = self._io.read_u4be()
            self.padding_1 = self._io.read_u4be()
            self.pld_tlm_ack_cnt = self._io.read_u1()
            self.pld_cmd_cnt = self._io.read_u1()
            self.pld_tlm_to_cnt = self._io.read_u1()
            self.pld_tlm_nak_cnt = self._io.read_u1()
            self.spare_end = self._io.read_u8be()


    class SohRefsT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.position_wrt_eci1 = self._io.read_s4be()
            self.position_wrt_eci2 = self._io.read_s4be()
            self.position_wrt_eci3 = self._io.read_s4be()
            self.velocity_wrt_eci1 = self._io.read_s4be()
            self.velocity_wrt_eci2 = self._io.read_s4be()
            self.velocity_wrt_eci3 = self._io.read_s4be()
            self.refs_valid = self._io.read_u1()


    class SohAttDetT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.q_body_wrt_eci1 = self._io.read_s4be()
            self.q_body_wrt_eci2 = self._io.read_s4be()
            self.q_body_wrt_eci3 = self._io.read_s4be()
            self.q_body_wrt_eci4 = self._io.read_s4be()
            self.body_rate1 = self._io.read_s4be()
            self.body_rate2 = self._io.read_s4be()
            self.body_rate3 = self._io.read_s4be()
            self.bad_att_timer = self._io.read_u4be()
            self.bad_rate_timer = self._io.read_u4be()
            self.reinit_count = self._io.read_u4be()
            self.attitude_valid = self._io.read_u1()
            self.meas_att_valid = self._io.read_u1()
            self.meas_rate_valid = self._io.read_u1()
            self.tracker_used = self._io.read_u1()


    class SohCommandTlmT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.cmd_status = self._io.read_u1()
            self.realtime_cmd_accept_count = self._io.read_u1()
            self.realtime_cmd_reject_count = self._io.read_u1()
            self.stored_cmd_accept_count = self._io.read_u1()
            self.stored_cmd_reject_count = self._io.read_u1()
            self.macros_executing_pack1 = self._io.read_u1()
            self.macros_executing_pack2 = self._io.read_u1()


    class Ax25InfoData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ccsds_space_packet = Cute.CcsdsSpacePacketT(self._io, self, self._root)






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO
import satnogsdecoders.process


if getattr(kaitaistruct, 'API_VERSION', (0, 9)) < (0, 9):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Alsat1n(KaitaiStruct):
    """:field callsign: callsign
    :field strx_header_seq: alsat1n_payload.strx_header.strx_header_seq
    :field strx_header_len: alsat1n_payload.strx_header.strx_header_len
    :field strx_header_id: alsat1n_payload.strx_header.strx_header_id
    :field payload_id: alsat1n_payload.ssc_header.payload_id
    :field msg_id: alsat1n_payload.ssc_header.msg_id
    :field response_code: alsat1n_payload.ssc_header.response_code
    :field p8_state: alsat1n_payload.ssc_channel.payload_type.msg_type.p8_state
    :field p8_current: alsat1n_payload.ssc_channel.payload_type.msg_type.p8_current
    :field p8_voltage: alsat1n_payload.ssc_channel.payload_type.msg_type.p8_voltage
    :field p7_state: alsat1n_payload.ssc_channel.payload_type.msg_type.p7_state
    :field p7_current: alsat1n_payload.ssc_channel.payload_type.msg_type.p7_current
    :field p7_voltage: alsat1n_payload.ssc_channel.payload_type.msg_type.p7_voltage
    :field ipcm5v: alsat1n_payload.ssc_channel.payload_type.msg_type.ipcm5v
    :field ipcm3v3: alsat1n_payload.ssc_channel.payload_type.msg_type.ipcm3v3
    :field ipcmbatv: alsat1n_payload.ssc_channel.payload_type.msg_type.ipcmbatv
    :field vpcmbatv: alsat1n_payload.ssc_channel.payload_type.msg_type.vpcmbatv
    :field eps_temperature: alsat1n_payload.ssc_channel.payload_type.msg_type.eps_temperature
    :field s1_state_3v3: alsat1n_payload.ssc_channel.payload_type.msg_type.s1_state_3v3
    :field s1_current_3v3: alsat1n_payload.ssc_channel.payload_type.msg_type.s1_current_3v3
    :field s1_voltage_3v3: alsat1n_payload.ssc_channel.payload_type.msg_type.s1_voltage_3v3
    :field s2_state_5v: alsat1n_payload.ssc_channel.payload_type.msg_type.s2_state_5v
    :field s2_current_5v: alsat1n_payload.ssc_channel.payload_type.msg_type.s2_current_5v
    :field s2_voltage_5v: alsat1n_payload.ssc_channel.payload_type.msg_type.s2_voltage_5v
    :field pdm_uptime_payload_h: alsat1n_payload.ssc_channel.payload_type.msg_type.pdm_uptime_payload_h
    :field pdm_uptime_payload_l: alsat1n_payload.ssc_channel.payload_type.msg_type.pdm_uptime_payload_l
    :field pdm_uptime_platform_h: alsat1n_payload.ssc_channel.payload_type.msg_type.pdm_uptime_platform_h
    :field pdm_uptime_platform_l: alsat1n_payload.ssc_channel.payload_type.msg_type.pdm_uptime_platform_l
    :field software_ident: alsat1n_payload.ssc_channel.payload_type.msg_type.software_ident
    :field uptime: alsat1n_payload.ssc_channel.payload_type.msg_type.uptime
    :field eps_voltage_battery: alsat1n_payload.ssc_channel.payload_type.msg_type.eps_voltage_battery
    :field eps_current_battery: alsat1n_payload.ssc_channel.payload_type.msg_type.eps_current_battery
    :field safe_mode: alsat1n_payload.ssc_channel.payload_type.msg_type.safe_mode
    :field safe_reason: alsat1n_payload.ssc_channel.payload_type.msg_type.safe_reason
    :field unix_time: alsat1n_payload.ssc_channel.payload_type.msg_type.unix_time
    :field reboot_num: alsat1n_payload.ssc_channel.payload_type.msg_type.reboot_num
    :field reboot_cause: alsat1n_payload.ssc_channel.payload_type.msg_type.reboot_cause
    :field i2c_traffic_cnt: alsat1n_payload.ssc_channel.payload_type.msg_type.i2c_traffic_cnt
    :field watchdog_time_remaining: alsat1n_payload.ssc_channel.payload_type.msg_type.watchdog_time_remaining
    :field amrad: alsat1n_payload.ssc_channel.payload_type.msg_type.amrad
    :field current_packet: alsat1n_payload.ssc_channel.payload_type.msg_type.current_packet
    :field block_id: alsat1n_payload.ssc_channel.payload_type.msg_type.block_id
    :field file_data: alsat1n_payload.ssc_channel.payload_type.msg_type.bin_file_data.file_data
    :field file_store: alsat1n_payload.ssc_channel.payload_type.msg_type.file_store
    :field file_type: alsat1n_payload.ssc_channel.payload_type.msg_type.file_type
    :field file_count: alsat1n_payload.ssc_channel.payload_type.msg_type.file_count
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.callsign = (KaitaiStream.bytes_terminate(self._io.read_bytes(5), 0, False)).decode(u"ASCII")
        _on = self.callsign
        if _on == u"AL1N":
            self.alsat1n_payload = Alsat1n.Alsat1nPayloadT(self._io, self, self._root)

    class WatchdogTimeRemaining(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.watchdog_time_remaining = self._io.read_u4le()


    class AmradMsg(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.amrad = (self._io.read_bytes(40)).decode(u"ASCII")


    class PdmPlatform(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdm_uptime_platform_h = self._io.read_u4le()
            self.pdm_uptime_platform_l = self._io.read_u4le()


    class EpsPlatform(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.s1_state_3v3 = self._io.read_u1()
            self.s1_current_3v3 = self._io.read_u2le()
            self.s1_voltage_3v3 = self._io.read_u2le()
            self.s2_state_5v = self._io.read_u1()
            self.s2_current_5v = self._io.read_u2le()
            self.s2_voltage_5v = self._io.read_u2le()


    class P7Psu(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.p7_state = self._io.read_u1()
            self.p7_current = self._io.read_u2le()
            self.p7_voltage = self._io.read_u2le()


    class SscHeaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.payload_id = self._io.read_u1()
            self.msg_id = self._io.read_u1()
            self.response_code = self._io.read_u1()


    class StrxHeaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.strx_header_seq = self._io.read_u1()
            self.strx_header_len = self._io.read_u2le()
            self.strx_header_id = self._io.read_u2le()


    class DownloadData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.current_packet = self._io.read_u2le()
            self.block_id = self._io.read_u2le()
            self._raw__raw_bin_file_data = self._io.read_bytes_full()
            _process = satnogsdecoders.process.B85encode()
            self._raw_bin_file_data = _process.decode(self._raw__raw_bin_file_data)
            _io__raw_bin_file_data = KaitaiStream(BytesIO(self._raw_bin_file_data))
            self.bin_file_data = Alsat1n.EncodedDataT(_io__raw_bin_file_data, self, self._root)


    class EncodedDataT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.file_data = (self._io.read_bytes_full()).decode(u"ASCII")


    class SscChannelT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self._parent.ssc_header.payload_id
            if _on == 5:
                self.payload_type = Alsat1n.Obc(self._io, self, self._root)
            elif _on == 19:
                self.payload_type = Alsat1n.File(self._io, self, self._root)
            elif _on == 46:
                self.payload_type = Alsat1n.Eps(self._io, self, self._root)


    class I2cTraffic(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.i2c_traffic_cnt = self._io.read_u4le()


    class PdmPayload(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pdm_uptime_payload_h = self._io.read_u4le()
            self.pdm_uptime_payload_l = self._io.read_u4le()


    class Eps(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self._parent._parent.ssc_header.msg_id
            if _on == 244:
                self.msg_type = Alsat1n.EpsPlatform(self._io, self, self._root)
            elif _on == 161:
                self.msg_type = Alsat1n.P7Psu(self._io, self, self._root)
            elif _on == 63:
                self.msg_type = Alsat1n.EpsPsuCurrent5v(self._io, self, self._root)
            elif _on == 166:
                self.msg_type = Alsat1n.P8Psu(self._io, self, self._root)
            elif _on == 65:
                self.msg_type = Alsat1n.EpsPsuCurrent3v3(self._io, self, self._root)
            elif _on == 122:
                self.msg_type = Alsat1n.PdmPlatform(self._io, self, self._root)
            elif _on == 240:
                self.msg_type = Alsat1n.EpsSys(self._io, self, self._root)
            elif _on == 175:
                self.msg_type = Alsat1n.PdmPayload(self._io, self, self._root)


    class Alsat1nPayloadT(KaitaiStruct):
        """
        .. seealso::
           Source - https://amsat-uk.org/2016/09/24/alsat-1n-pratham-launch/
        """
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.strx_header = Alsat1n.StrxHeaderT(self._io, self, self._root)
            self.ssc_header = Alsat1n.SscHeaderT(self._io, self, self._root)
            self.ssc_channel = Alsat1n.SscChannelT(self._io, self, self._root)


    class EpsPsuCurrent3v3(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ipcm3v3 = self._io.read_u2le()


    class File(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self._parent._parent.ssc_header.msg_id
            if _on == 21:
                self.msg_type = Alsat1n.DownloadData(self._io, self, self._root)
            elif _on == 30:
                self.msg_type = Alsat1n.FileCount(self._io, self, self._root)


    class FileCount(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.file_store = self._io.read_u1()
            self.file_type = self._io.read_u1()
            self.file_count = self._io.read_u2le()


    class Obc(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self._parent._parent.ssc_header.msg_id
            if _on == 1:
                self.msg_type = Alsat1n.ObcHealth(self._io, self, self._root)
            elif _on == 32:
                self.msg_type = Alsat1n.I2cTraffic(self._io, self, self._root)
            elif _on == 127:
                self.msg_type = Alsat1n.WatchdogTimeRemaining(self._io, self, self._root)
            elif _on == 176:
                self.msg_type = Alsat1n.AmradMsg(self._io, self, self._root)


    class EpsSys(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ipcmbatv = self._io.read_u2le()
            self.vpcmbatv = self._io.read_u2le()
            self.eps_temperature = self._io.read_u2le()


    class P8Psu(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.p8_state = self._io.read_u1()
            self.p8_current = self._io.read_u2le()
            self.p8_voltage = self._io.read_u2le()


    class ObcHealth(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.software_ident = self._io.read_u1()
            self.uptime = self._io.read_u4le()
            self.eps_voltage_battery = self._io.read_u2le()
            self.eps_current_battery = self._io.read_u2le()
            self.safe_mode = self._io.read_u1()
            self.safe_reason = self._io.read_u1()
            self.unix_time = self._io.read_u4le()
            self.reboot_num = self._io.read_u1()
            self.reboot_cause = self._io.read_u1()


    class EpsPsuCurrent5v(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ipcm5v = self._io.read_u2le()






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if getattr(kaitaistruct, 'API_VERSION', (0, 9)) < (0, 9):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Acrux1(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field tx_count: ax25_frame.payload.msp_payload.tx_count
    :field rx_count: ax25_frame.payload.msp_payload.rx_count
    :field rx_valid: ax25_frame.payload.msp_payload.rx_valid
    :field payload_type: ax25_frame.payload.msp_payload.payload_type
    :field comouti1: ax25_frame.payload.msp_payload.comouti1
    :field comoutv1: ax25_frame.payload.msp_payload.comoutv1
    :field comouti2: ax25_frame.payload.msp_payload.comouti2
    :field comoutv2: ax25_frame.payload.msp_payload.comoutv2
    :field comt2: ax25_frame.payload.msp_payload.comt2
    :field epsadcbatv1: ax25_frame.payload.msp_payload.epsadcbatv1
    :field epsloadi1: ax25_frame.payload.msp_payload.epsloadi1
    :field epsadcbatv2: ax25_frame.payload.msp_payload.epsadcbatv2
    :field epsboostini2: ax25_frame.payload.msp_payload.epsboostini2
    :field epsrail1: ax25_frame.payload.msp_payload.epsrail1
    :field epsrail2: ax25_frame.payload.msp_payload.epsrail2
    :field epstoppanelv: ax25_frame.payload.msp_payload.epstoppanelv
    :field epstoppaneli: ax25_frame.payload.msp_payload.epstoppaneli
    :field epst1: ax25_frame.payload.msp_payload.epst1
    :field epst2: ax25_frame.payload.msp_payload.epst2
    :field xposv: ax25_frame.payload.msp_payload.xposv
    :field xposi: ax25_frame.payload.msp_payload.xposi
    :field xpost1: ax25_frame.payload.msp_payload.xpost1
    :field yposv: ax25_frame.payload.msp_payload.yposv
    :field yposi: ax25_frame.payload.msp_payload.yposi
    :field ypost1: ax25_frame.payload.msp_payload.ypost1
    :field xnegv: ax25_frame.payload.msp_payload.xnegv
    :field xnegi: ax25_frame.payload.msp_payload.xnegi
    :field xnegt1: ax25_frame.payload.msp_payload.xnegt1
    :field ynegv: ax25_frame.payload.msp_payload.ynegv
    :field ynegi: ax25_frame.payload.msp_payload.ynegi
    :field ynegt1: ax25_frame.payload.msp_payload.ynegt1
    :field znegv: ax25_frame.payload.msp_payload.znegv
    :field znegi: ax25_frame.payload.msp_payload.znegi
    :field znegt1: ax25_frame.payload.msp_payload.znegt1
    :field zpost: ax25_frame.payload.msp_payload.zpost
    :field cdhtime: ax25_frame.payload.msp_payload.cdhtime
    :field swcdhlastreboot: ax25_frame.payload.msp_payload.swcdhlastreboot
    :field swsequence: ax25_frame.payload.msp_payload.swsequence
    :field outreachmessage: ax25_frame.payload.msp_payload.outreachmessage
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Acrux1.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Acrux1.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = Acrux1.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = Acrux1.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = Acrux1.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = Acrux1.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = Acrux1.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = Acrux1.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Acrux1.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Acrux1.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Acrux1.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Acrux1.SsidMask(self._io, self, self._root)
            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.msp_payload = Acrux1.MspPayloadT(self._io, self, self._root)
            self.zero_padding = self._io.read_bytes(91)
            self.fec8_rs_checksum = self._io.read_bytes(32)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return getattr(self, '_m_ssid', None)


    class MspPayloadT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.tx_count = self._io.read_u1()
            self.rx_count = self._io.read_u1()
            self.rx_valid = self._io.read_u1()
            self.payload_type = self._io.read_u1()
            self.comouti1 = self._io.read_s2le()
            self.comoutv1 = self._io.read_s2le()
            self.comouti2 = self._io.read_s2le()
            self.comoutv2 = self._io.read_s2le()
            self.comt2 = self._io.read_s2le()
            self.epsadcbatv1 = self._io.read_s2le()
            self.epsloadi1 = self._io.read_s2le()
            self.epsadcbatv2 = self._io.read_s2le()
            self.epsboostini2 = self._io.read_s2le()
            self.epsrail1 = self._io.read_s2le()
            self.epsrail2 = self._io.read_s2le()
            self.epstoppanelv = self._io.read_s2le()
            self.epstoppaneli = self._io.read_s2le()
            self.epst1 = self._io.read_s2le()
            self.epst2 = self._io.read_s2le()
            self.xposv = self._io.read_s2le()
            self.xposi = self._io.read_s2le()
            self.xpost1 = self._io.read_s2le()
            self.yposv = self._io.read_s2le()
            self.yposi = self._io.read_s2le()
            self.ypost1 = self._io.read_s2le()
            self.xnegv = self._io.read_s2le()
            self.xnegi = self._io.read_s2le()
            self.xnegt1 = self._io.read_s2le()
            self.ynegv = self._io.read_s2le()
            self.ynegi = self._io.read_s2le()
            self.ynegt1 = self._io.read_s2le()
            self.znegv = self._io.read_s2le()
            self.znegi = self._io.read_s2le()
            self.znegt1 = self._io.read_s2le()
            self.zpost = self._io.read_s2le()
            self.cdhtime = self._io.read_u8le()
            self.swcdhlastreboot = self._io.read_u8le()
            self.swsequence = self._io.read_u2le()
            self.outreachmessage = (self._io.read_bytes(48)).decode(u"ASCII")


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Acrux1.Callsign(_io__raw_callsign_ror, self, self._root)






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if getattr(kaitaistruct, 'API_VERSION', (0, 9)) < (0, 9):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Oresat05(KaitaiStruct):
    """:field callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field ssid_mask: ax25_frame.ax25_header.dest_ssid_raw.ssid_mask
    :field ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field src_callsign_raw_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid_raw_ssid_mask: ax25_frame.ax25_header.src_ssid_raw.ssid_mask
    :field src_ssid_raw_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field beacon_start_chars: ax25_frame.payload.ax25_info.beacon_start_chars
    :field satellite_id: ax25_frame.payload.ax25_info.satellite_id
    :field beacon_revision: ax25_frame.payload.ax25_info.beacon_revision
    :field status: ax25_frame.payload.ax25_info.status
    :field mode: ax25_frame.payload.ax25_info.mode
    :field system_uptime: ax25_frame.payload.ax25_info.system_uptime
    :field system_unix_time: ax25_frame.payload.ax25_info.system_unix_time
    :field system_power_cycles: ax25_frame.payload.ax25_info.system_power_cycles
    :field system_storage_percent: ax25_frame.payload.ax25_info.system_storage_percent
    :field lband_rx_bytes: ax25_frame.payload.ax25_info.lband_rx_bytes
    :field lband_rx_packets: ax25_frame.payload.ax25_info.lband_rx_packets
    :field lband_rssi: ax25_frame.payload.ax25_info.lband_rssi
    :field lband_synth_relock_count: ax25_frame.payload.ax25_info.lband_synth_relock_count
    :field uhf_rx_bytes: ax25_frame.payload.ax25_info.uhf_rx_bytes
    :field uhf_rx_packets: ax25_frame.payload.ax25_info.uhf_rx_packets
    :field uhf_rssi: ax25_frame.payload.ax25_info.uhf_rssi
    :field edl_sequence_count: ax25_frame.payload.ax25_info.edl_sequence_count
    :field edl_rejected_count: ax25_frame.payload.ax25_info.edl_rejected_count
    :field fread_cache_length: ax25_frame.payload.ax25_info.fread_cache_length
    :field fwrite_cache_length: ax25_frame.payload.ax25_info.fwrite_cache_length
    :field updater_cache_length: ax25_frame.payload.ax25_info.updater_cache_length
    :field adcs_manager_mode: ax25_frame.payload.ax25_info.adcs_manager_mode
    :field battery_1_pack_1_vbatt: ax25_frame.payload.ax25_info.battery_1_pack_1_vbatt
    :field battery_1_pack_1_vcell: ax25_frame.payload.ax25_info.battery_1_pack_1_vcell
    :field battery_1_pack_1_vcell_max: ax25_frame.payload.ax25_info.battery_1_pack_1_vcell_max
    :field battery_1_pack_1_vcell_min: ax25_frame.payload.ax25_info.battery_1_pack_1_vcell_min
    :field battery_1_pack_1_vcell_1: ax25_frame.payload.ax25_info.battery_1_pack_1_vcell_1
    :field battery_1_pack_1_vcell_2: ax25_frame.payload.ax25_info.battery_1_pack_1_vcell_2
    :field battery_1_pack_1_vcell_avg: ax25_frame.payload.ax25_info.battery_1_pack_1_vcell_avg
    :field battery_1_pack_1_temperature: ax25_frame.payload.ax25_info.battery_1_pack_1_temperature
    :field battery_1_pack_1_temperature_avg: ax25_frame.payload.ax25_info.battery_1_pack_1_temperature_avg
    :field battery_1_pack_1_temperature_max: ax25_frame.payload.ax25_info.battery_1_pack_1_temperature_max
    :field battery_1_pack_1_temperature_min: ax25_frame.payload.ax25_info.battery_1_pack_1_temperature_min
    :field battery_1_pack_1_current: ax25_frame.payload.ax25_info.battery_1_pack_1_current
    :field battery_1_pack_1_current_avg: ax25_frame.payload.ax25_info.battery_1_pack_1_current_avg
    :field battery_1_pack_1_current_max: ax25_frame.payload.ax25_info.battery_1_pack_1_current_max
    :field battery_1_pack_1_current_min: ax25_frame.payload.ax25_info.battery_1_pack_1_current_min
    :field battery_1_pack_1_status: ax25_frame.payload.ax25_info.battery_1_pack_1_status
    :field battery_1_pack_1_reported_state_of_charge: ax25_frame.payload.ax25_info.battery_1_pack_1_reported_state_of_charge
    :field battery_1_pack_1_full_capacity: ax25_frame.payload.ax25_info.battery_1_pack_1_full_capacity
    :field battery_1_pack_1_reported_capacity: ax25_frame.payload.ax25_info.battery_1_pack_1_reported_capacity
    :field battery_1_pack_2_vbatt: ax25_frame.payload.ax25_info.battery_1_pack_2_vbatt
    :field battery_1_pack_2_vcell: ax25_frame.payload.ax25_info.battery_1_pack_2_vcell
    :field battery_1_pack_2_vcell_max: ax25_frame.payload.ax25_info.battery_1_pack_2_vcell_max
    :field battery_1_pack_2_vcell_min: ax25_frame.payload.ax25_info.battery_1_pack_2_vcell_min
    :field battery_1_pack_2_vcell_1: ax25_frame.payload.ax25_info.battery_1_pack_2_vcell_1
    :field battery_1_pack_2_vcell_2: ax25_frame.payload.ax25_info.battery_1_pack_2_vcell_2
    :field battery_1_pack_2_vcell_avg: ax25_frame.payload.ax25_info.battery_1_pack_2_vcell_avg
    :field battery_1_pack_2_temperature: ax25_frame.payload.ax25_info.battery_1_pack_2_temperature
    :field battery_1_pack_2_temperature_avg: ax25_frame.payload.ax25_info.battery_1_pack_2_temperature_avg
    :field battery_1_pack_2_temperature_max: ax25_frame.payload.ax25_info.battery_1_pack_2_temperature_max
    :field battery_1_pack_2_temperature_min: ax25_frame.payload.ax25_info.battery_1_pack_2_temperature_min
    :field battery_1_pack_2_current: ax25_frame.payload.ax25_info.battery_1_pack_2_current
    :field battery_1_pack_2_current_avg: ax25_frame.payload.ax25_info.battery_1_pack_2_current_avg
    :field battery_1_pack_2_current_max: ax25_frame.payload.ax25_info.battery_1_pack_2_current_max
    :field battery_1_pack_2_current_min: ax25_frame.payload.ax25_info.battery_1_pack_2_current_min
    :field battery_1_pack_2_status: ax25_frame.payload.ax25_info.battery_1_pack_2_status
    :field battery_1_pack_2_reported_state_of_charge: ax25_frame.payload.ax25_info.battery_1_pack_2_reported_state_of_charge
    :field battery_1_pack_2_full_capacity: ax25_frame.payload.ax25_info.battery_1_pack_2_full_capacity
    :field battery_1_pack_2_reported_capacity: ax25_frame.payload.ax25_info.battery_1_pack_2_reported_capacity
    :field solar_1_output_voltage_avg: ax25_frame.payload.ax25_info.solar_1_output_voltage_avg
    :field solar_1_output_current_avg: ax25_frame.payload.ax25_info.solar_1_output_current_avg
    :field solar_1_output_power_avg: ax25_frame.payload.ax25_info.solar_1_output_power_avg
    :field solar_1_output_voltage_max: ax25_frame.payload.ax25_info.solar_1_output_voltage_max
    :field solar_1_output_current_max: ax25_frame.payload.ax25_info.solar_1_output_current_max
    :field solar_1_output_power_max: ax25_frame.payload.ax25_info.solar_1_output_power_max
    :field solar_1_output_energy: ax25_frame.payload.ax25_info.solar_1_output_energy
    :field solar_2_output_voltage_avg: ax25_frame.payload.ax25_info.solar_2_output_voltage_avg
    :field solar_2_output_current_avg: ax25_frame.payload.ax25_info.solar_2_output_current_avg
    :field solar_2_output_power_avg: ax25_frame.payload.ax25_info.solar_2_output_power_avg
    :field solar_2_output_voltage_max: ax25_frame.payload.ax25_info.solar_2_output_voltage_max
    :field solar_2_output_current_max: ax25_frame.payload.ax25_info.solar_2_output_current_max
    :field solar_2_output_power_max: ax25_frame.payload.ax25_info.solar_2_output_power_max
    :field solar_2_output_energy: ax25_frame.payload.ax25_info.solar_2_output_energy
    :field solar_3_output_voltage_avg: ax25_frame.payload.ax25_info.solar_3_output_voltage_avg
    :field solar_3_output_current_avg: ax25_frame.payload.ax25_info.solar_3_output_current_avg
    :field solar_3_output_power_avg: ax25_frame.payload.ax25_info.solar_3_output_power_avg
    :field solar_3_output_voltage_max: ax25_frame.payload.ax25_info.solar_3_output_voltage_max
    :field solar_3_output_current_max: ax25_frame.payload.ax25_info.solar_3_output_current_max
    :field solar_3_output_power_max: ax25_frame.payload.ax25_info.solar_3_output_power_max
    :field solar_3_output_energy: ax25_frame.payload.ax25_info.solar_3_output_energy
    :field solar_4_output_voltage_avg: ax25_frame.payload.ax25_info.solar_4_output_voltage_avg
    :field solar_4_output_current_avg: ax25_frame.payload.ax25_info.solar_4_output_current_avg
    :field solar_4_output_power_avg: ax25_frame.payload.ax25_info.solar_4_output_power_avg
    :field solar_4_output_voltage_max: ax25_frame.payload.ax25_info.solar_4_output_voltage_max
    :field solar_4_output_current_max: ax25_frame.payload.ax25_info.solar_4_output_current_max
    :field solar_4_output_power_max: ax25_frame.payload.ax25_info.solar_4_output_power_max
    :field solar_4_output_energy: ax25_frame.payload.ax25_info.solar_4_output_energy
    :field solar_5_output_voltage_avg: ax25_frame.payload.ax25_info.solar_5_output_voltage_avg
    :field solar_5_output_current_avg: ax25_frame.payload.ax25_info.solar_5_output_current_avg
    :field solar_5_output_power_avg: ax25_frame.payload.ax25_info.solar_5_output_power_avg
    :field solar_5_output_voltage_max: ax25_frame.payload.ax25_info.solar_5_output_voltage_max
    :field solar_5_output_current_max: ax25_frame.payload.ax25_info.solar_5_output_current_max
    :field solar_5_output_power_max: ax25_frame.payload.ax25_info.solar_5_output_power_max
    :field solar_5_output_energy: ax25_frame.payload.ax25_info.solar_5_output_energy
    :field solar_6_output_voltage_avg: ax25_frame.payload.ax25_info.solar_6_output_voltage_avg
    :field solar_6_output_current_avg: ax25_frame.payload.ax25_info.solar_6_output_current_avg
    :field solar_6_output_power_avg: ax25_frame.payload.ax25_info.solar_6_output_power_avg
    :field solar_6_output_voltage_max: ax25_frame.payload.ax25_info.solar_6_output_voltage_max
    :field solar_6_output_current_max: ax25_frame.payload.ax25_info.solar_6_output_current_max
    :field solar_6_output_power_max: ax25_frame.payload.ax25_info.solar_6_output_power_max
    :field solar_6_output_energy: ax25_frame.payload.ax25_info.solar_6_output_energy
    :field star_tracker_1_system_storage_percent: ax25_frame.payload.ax25_info.star_tracker_1_system_storage_percent
    :field star_tracker_1_status: ax25_frame.payload.ax25_info.star_tracker_1_status
    :field gps_system_storage_percent: ax25_frame.payload.ax25_info.gps_system_storage_percent
    :field gps_status: ax25_frame.payload.ax25_info.gps_status
    :field gps_skytraq_number_of_sv: ax25_frame.payload.ax25_info.gps_skytraq_number_of_sv
    :field gps_skytraq_fix_mode: ax25_frame.payload.ax25_info.gps_skytraq_fix_mode
    :field adcs_gyroscope_roll_rate: ax25_frame.payload.ax25_info.adcs_gyroscope_roll_rate
    :field adcs_gyroscope_pitch_rate: ax25_frame.payload.ax25_info.adcs_gyroscope_pitch_rate
    :field adcs_gyroscope_yaw_rate: ax25_frame.payload.ax25_info.adcs_gyroscope_yaw_rate
    :field dxwifi_system_storage_percent: ax25_frame.payload.ax25_info.dxwifi_system_storage_percent
    :field dxwifi_status: ax25_frame.payload.ax25_info.dxwifi_status
    :field dxwifi_radio_temperature: ax25_frame.payload.ax25_info.dxwifi_radio_temperature
    :field cfc_processor_system_storage_percent: ax25_frame.payload.ax25_info.cfc_processor_system_storage_percent
    :field cfc_processor_camera_status: ax25_frame.payload.ax25_info.cfc_processor_camera_status
    :field cfc_processor_camera_temperature: ax25_frame.payload.ax25_info.cfc_processor_camera_temperature
    :field cfc_processor_tec_status: ax25_frame.payload.ax25_info.cfc_processor_tec_status
    :field refcs: ax25_frame.ax25_trunk.refcs
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Oresat05.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Oresat05.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = Oresat05.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = Oresat05.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = Oresat05.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = Oresat05.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = Oresat05.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = Oresat05.IFrame(self._io, self, self._root)
            self.ax25_trunk = Oresat05.Ax25Trunk(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Oresat05.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Oresat05.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Oresat05.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Oresat05.SsidMask(self._io, self, self._root)
            if (self.src_ssid_raw.ssid_mask & 1) == 0:
                self.repeater = Oresat05.Repeater(self._io, self, self._root)

            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes(216)
            _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = Oresat05.Ax25InfoData(_io__raw_ax25_info, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")
            if not  ((self.callsign == u"KJ7SAT") or (self.callsign == u"SPACE ")) :
                raise kaitaistruct.ValidationNotAnyOfError(self.callsign, self._io, u"/types/callsign/seq/0")


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes(216)
            _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = Oresat05.Ax25InfoData(_io__raw_ax25_info, self, self._root)


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return getattr(self, '_m_ssid', None)


    class Repeaters(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_callsign_raw = Oresat05.CallsignRaw(self._io, self, self._root)
            self.rpt_ssid_raw = Oresat05.SsidMask(self._io, self, self._root)


    class Repeater(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.rpt_instance = []
            i = 0
            while True:
                _ = Oresat05.Repeaters(self._io, self, self._root)
                self.rpt_instance.append(_)
                if (_.rpt_ssid_raw.ssid_mask & 1) == 1:
                    break
                i += 1


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Oresat05.Callsign(_io__raw_callsign_ror, self, self._root)


    class Ax25Trunk(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.refcs = self._io.read_u4le()


    class Ax25InfoData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.beacon_start_chars = (self._io.read_bytes(3)).decode(u"ASCII")
            self.satellite_id = self._io.read_u1()
            self.beacon_revision = self._io.read_u1()
            self.status = self._io.read_u1()
            self.mode = self._io.read_u1()
            self.system_uptime = self._io.read_u4le()
            self.system_unix_time = self._io.read_u4le()
            self.system_power_cycles = self._io.read_u2le()
            self.system_storage_percent = self._io.read_u1()
            self.lband_rx_bytes = self._io.read_u4le()
            self.lband_rx_packets = self._io.read_u4le()
            self.lband_rssi = self._io.read_s1()
            self.lband_synth_relock_count = self._io.read_u1()
            self.uhf_rx_bytes = self._io.read_u4le()
            self.uhf_rx_packets = self._io.read_u4le()
            self.uhf_rssi = self._io.read_s1()
            self.edl_sequence_count = self._io.read_u4le()
            self.edl_rejected_count = self._io.read_u4le()
            self.fread_cache_length = self._io.read_u1()
            self.fwrite_cache_length = self._io.read_u1()
            self.updater_cache_length = self._io.read_u1()
            self.adcs_manager_mode = self._io.read_u1()
            self.battery_1_pack_1_vbatt = self._io.read_u2le()
            self.battery_1_pack_1_vcell = self._io.read_u2le()
            self.battery_1_pack_1_vcell_max = self._io.read_u2le()
            self.battery_1_pack_1_vcell_min = self._io.read_u2le()
            self.battery_1_pack_1_vcell_1 = self._io.read_u2le()
            self.battery_1_pack_1_vcell_2 = self._io.read_u2le()
            self.battery_1_pack_1_vcell_avg = self._io.read_u2le()
            self.battery_1_pack_1_temperature = self._io.read_s1()
            self.battery_1_pack_1_temperature_avg = self._io.read_s1()
            self.battery_1_pack_1_temperature_max = self._io.read_s1()
            self.battery_1_pack_1_temperature_min = self._io.read_s1()
            self.battery_1_pack_1_current = self._io.read_s2le()
            self.battery_1_pack_1_current_avg = self._io.read_s2le()
            self.battery_1_pack_1_current_max = self._io.read_s2le()
            self.battery_1_pack_1_current_min = self._io.read_s2le()
            self.battery_1_pack_1_status = self._io.read_u1()
            self.battery_1_pack_1_reported_state_of_charge = self._io.read_u1()
            self.battery_1_pack_1_full_capacity = self._io.read_u2le()
            self.battery_1_pack_1_reported_capacity = self._io.read_u2le()
            self.battery_1_pack_2_vbatt = self._io.read_u2le()
            self.battery_1_pack_2_vcell = self._io.read_u2le()
            self.battery_1_pack_2_vcell_max = self._io.read_u2le()
            self.battery_1_pack_2_vcell_min = self._io.read_u2le()
            self.battery_1_pack_2_vcell_1 = self._io.read_u2le()
            self.battery_1_pack_2_vcell_2 = self._io.read_u2le()
            self.battery_1_pack_2_vcell_avg = self._io.read_u2le()
            self.battery_1_pack_2_temperature = self._io.read_s1()
            self.battery_1_pack_2_temperature_avg = self._io.read_s1()
            self.battery_1_pack_2_temperature_max = self._io.read_s1()
            self.battery_1_pack_2_temperature_min = self._io.read_s1()
            self.battery_1_pack_2_current = self._io.read_s2le()
            self.battery_1_pack_2_current_avg = self._io.read_s2le()
            self.battery_1_pack_2_current_max = self._io.read_s2le()
            self.battery_1_pack_2_current_min = self._io.read_s2le()
            self.battery_1_pack_2_status = self._io.read_u1()
            self.battery_1_pack_2_reported_state_of_charge = self._io.read_u1()
            self.battery_1_pack_2_full_capacity = self._io.read_u2le()
            self.battery_1_pack_2_reported_capacity = self._io.read_u2le()
            self.solar_1_output_voltage_avg = self._io.read_u2le()
            self.solar_1_output_current_avg = self._io.read_s2le()
            self.solar_1_output_power_avg = self._io.read_u2le()
            self.solar_1_output_voltage_max = self._io.read_u2le()
            self.solar_1_output_current_max = self._io.read_s2le()
            self.solar_1_output_power_max = self._io.read_u2le()
            self.solar_1_output_energy = self._io.read_u2le()
            self.solar_2_output_voltage_avg = self._io.read_u2le()
            self.solar_2_output_current_avg = self._io.read_s2le()
            self.solar_2_output_power_avg = self._io.read_u2le()
            self.solar_2_output_voltage_max = self._io.read_u2le()
            self.solar_2_output_current_max = self._io.read_s2le()
            self.solar_2_output_power_max = self._io.read_u2le()
            self.solar_2_output_energy = self._io.read_u2le()
            self.solar_3_output_voltage_avg = self._io.read_u2le()
            self.solar_3_output_current_avg = self._io.read_s2le()
            self.solar_3_output_power_avg = self._io.read_u2le()
            self.solar_3_output_voltage_max = self._io.read_u2le()
            self.solar_3_output_current_max = self._io.read_s2le()
            self.solar_3_output_power_max = self._io.read_u2le()
            self.solar_3_output_energy = self._io.read_u2le()
            self.solar_4_output_voltage_avg = self._io.read_u2le()
            self.solar_4_output_current_avg = self._io.read_s2le()
            self.solar_4_output_power_avg = self._io.read_u2le()
            self.solar_4_output_voltage_max = self._io.read_u2le()
            self.solar_4_output_current_max = self._io.read_s2le()
            self.solar_4_output_power_max = self._io.read_u2le()
            self.solar_4_output_energy = self._io.read_u2le()
            self.solar_5_output_voltage_avg = self._io.read_u2le()
            self.solar_5_output_current_avg = self._io.read_s2le()
            self.solar_5_output_power_avg = self._io.read_u2le()
            self.solar_5_output_voltage_max = self._io.read_u2le()
            self.solar_5_output_current_max = self._io.read_s2le()
            self.solar_5_output_power_max = self._io.read_u2le()
            self.solar_5_output_energy = self._io.read_u2le()
            self.solar_6_output_voltage_avg = self._io.read_u2le()
            self.solar_6_output_current_avg = self._io.read_s2le()
            self.solar_6_output_power_avg = self._io.read_u2le()
            self.solar_6_output_voltage_max = self._io.read_u2le()
            self.solar_6_output_current_max = self._io.read_s2le()
            self.solar_6_output_power_max = self._io.read_u2le()
            self.solar_6_output_energy = self._io.read_u2le()
            self.star_tracker_1_system_storage_percent = self._io.read_u1()
            self.star_tracker_1_status = self._io.read_u1()
            self.gps_system_storage_percent = self._io.read_u1()
            self.gps_status = self._io.read_u1()
            self.gps_skytraq_number_of_sv = self._io.read_u1()
            self.gps_skytraq_fix_mode = self._io.read_u1()
            self.adcs_gyroscope_roll_rate = self._io.read_s2le()
            self.adcs_gyroscope_pitch_rate = self._io.read_s2le()
            self.adcs_gyroscope_yaw_rate = self._io.read_s2le()
            self.dxwifi_system_storage_percent = self._io.read_u1()
            self.dxwifi_status = self._io.read_u1()
            self.dxwifi_radio_temperature = self._io.read_s1()
            self.cfc_processor_system_storage_percent = self._io.read_u1()
            self.cfc_processor_camera_status = self._io.read_u1()
            self.cfc_processor_camera_temperature = self._io.read_s1()
            self.cfc_processor_tec_status = self._io.read_bits_int_be(1) != 0






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if getattr(kaitaistruct, 'API_VERSION', (0, 9)) < (0, 9):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Rhoksat(KaitaiStruct):
    """:field panel_temp: sp_telemetry.panel0.panel_temp
    :field panel_status: sp_telemetry.panel0.panel_status
    :field panel_voltage: sp_telemetry.panel0.panel_voltage
    :field panel_photodiode: sp_telemetry.panel0.panel_photodiode
    :field panel1_panel_temp: sp_telemetry.panel1.panel_temp
    :field panel1_panel_status: sp_telemetry.panel1.panel_status
    :field panel1_panel_voltage: sp_telemetry.panel1.panel_voltage
    :field panel1_panel_photodiode: sp_telemetry.panel1.panel_photodiode
    :field panel2_panel_temp: sp_telemetry.panel2.panel_temp
    :field panel2_panel_status: sp_telemetry.panel2.panel_status
    :field panel2_panel_voltage: sp_telemetry.panel2.panel_voltage
    :field panel2_panel_photodiode: sp_telemetry.panel2.panel_photodiode
    :field panel3_panel_temp: sp_telemetry.panel3.panel_temp
    :field panel3_panel_status: sp_telemetry.panel3.panel_status
    :field panel3_panel_voltage: sp_telemetry.panel3.panel_voltage
    :field panel3_panel_photodiode: sp_telemetry.panel3.panel_photodiode
    :field panel4_panel_temp: sp_telemetry.panel4.panel_temp
    :field panel4_panel_status: sp_telemetry.panel4.panel_status
    :field panel4_panel_voltage: sp_telemetry.panel4.panel_voltage
    :field panel4_panel_photodiode: sp_telemetry.panel4.panel_photodiode
    :field volt_brdsup: eps_telemetry.volt_brdsup
    :field volt: eps_telemetry.dist_input.volt
    :field current: eps_telemetry.dist_input.current
    :field power: eps_telemetry.dist_input.power
    :field batt_input_volt: eps_telemetry.batt_input.volt
    :field batt_input_current: eps_telemetry.batt_input.current
    :field batt_input_power: eps_telemetry.batt_input.power
    :field stat_obc_on: eps_telemetry.stat_obc_on
    :field stat_obc_ocf: eps_telemetry.stat_obc_ocf
    :field bat_stat: eps_telemetry.bat_stat
    :field temp: eps_telemetry.temp
    :field temp2: eps_telemetry.temp2
    :field temp3: eps_telemetry.temp3
    :field stid: eps_telemetry.status.reply_header.stid
    :field ivid: eps_telemetry.status.reply_header.ivid
    :field rc: eps_telemetry.status.reply_header.rc
    :field bid: eps_telemetry.status.reply_header.bid
    :field cmderrstat: eps_telemetry.status.reply_header.cmderrstat
    :field mode: eps_telemetry.status.mode
    :field conf: eps_telemetry.status.conf
    :field reset_cause: eps_telemetry.status.reset_cause
    :field uptime: eps_telemetry.status.uptime
    :field error: eps_telemetry.status.error
    :field rc_cnt_pwron: eps_telemetry.status.rc_cnt_pwron
    :field rc_cnt_wdg: eps_telemetry.status.rc_cnt_wdg
    :field rc_cnt_cmd: eps_telemetry.status.rc_cnt_cmd
    :field rc_cnt_pweron_mcu: eps_telemetry.status.rc_cnt_pweron_mcu
    :field rc_cnt_emlopo: eps_telemetry.status.rc_cnt_emlopo
    :field prevcmd_elapsed: eps_telemetry.status.prevcmd_elapsed
    :field ants_temperature: anta_telemetry.ants_temperature
    :field ants_deployment: anta_telemetry.ants_deployment
    :field ants_uptime: anta_telemetry.ants_uptime
    :field antb_telemetry_ants_temperature: antb_telemetry.ants_temperature
    :field antb_telemetry_ants_deployment: antb_telemetry.ants_deployment
    :field antb_telemetry_ants_uptime: antb_telemetry.ants_uptime
    :field imtq_system_state_mode: imtq_system_state.mode
    :field err: imtq_system_state.err
    :field imtq_system_state_conf: imtq_system_state.conf
    :field imtq_system_state_uptime: imtq_system_state.uptime
    :field x: imtq_magnetometer.cal_magf.x
    :field y: imtq_magnetometer.cal_magf.y
    :field z: imtq_magnetometer.cal_magf.z
    :field coilact: imtq_magnetometer.coilact
    :field last_detumble_time: last_detumble_time
    :field acc_x: acc.x
    :field acc_y: acc.y
    :field acc_z: acc.z
    :field gyro_x: gyro.x
    :field gyro_y: gyro.y
    :field gyro_z: gyro.z
    :field trxvu_mode: trxvu_mode
    :field onboard_time: onboard_time
    :field obc_up_time: obc_up_time
    :field num_reboots: num_reboots
    :field rtcok: rtcok
    :field storage_available_ram: storage_available_ram
    :field storage_available_sd: storage_available_sd
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.resetcounter = self._io.read_u4le()
        self.latest_time = self._io.read_u4le()
        self.sp_telemetry = Rhoksat.SpTelemetry(self._io, self, self._root)
        self.eps_telemetry = Rhoksat.EpsTelemetry(self._io, self, self._root)
        self.anta_telemetry = Rhoksat.IsisAntsTelemetry(self._io, self, self._root)
        self.antb_telemetry = Rhoksat.IsisAntsTelemetry(self._io, self, self._root)
        self.imtq_system_state = Rhoksat.ImtqSystemstateT(self._io, self, self._root)
        self.imtq_magnetometer = Rhoksat.ImtqCalMagfT(self._io, self, self._root)
        self.last_detumble_time = self._io.read_u4le()
        self.acc = Rhoksat.Axis(self._io, self, self._root)
        self.gyro = Rhoksat.Axis(self._io, self, self._root)
        self.trxvu_mode = self._io.read_u1()
        self.onboard_time = self._io.read_u4le()
        self.obc_up_time = self._io.read_u4le()
        self.num_reboots = self._io.read_u1()
        self.rtcok = self._io.read_u1()
        self.storage_available_ram = self._io.read_u4le()
        self.storage_available_sd = self._io.read_u4le()

    class IsisAntsTelemetry(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ants_temperature = self._io.read_u2le()
            self.ants_deployment = self._io.read_u2le()
            self.ants_uptime = self._io.read_u4le()


    class Panel(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.panel_temp = self._io.read_f4le()
            self.panel_status = self._io.read_u1()
            self.panel_voltage = self._io.read_u2le()
            self.panel_photodiode = self._io.read_u2le()


    class IsisEpsGetsystemstatusFromT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.reply_header = Rhoksat.IsisEpsReplyheaderT(self._io, self, self._root)
            self.mode = self._io.read_u1()
            self.conf = self._io.read_u1()
            self.reset_cause = self._io.read_u1()
            self.uptime = self._io.read_u4le()
            self.error = self._io.read_u2le()
            self.rc_cnt_pwron = self._io.read_u2le()
            self.rc_cnt_wdg = self._io.read_u2le()
            self.rc_cnt_cmd = self._io.read_u2le()
            self.rc_cnt_pweron_mcu = self._io.read_u2le()
            self.rc_cnt_emlopo = self._io.read_u2le()
            self.prevcmd_elapsed = self._io.read_u2le()


    class ImtqSystemstateT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.mode = self._io.read_u1()
            self.err = self._io.read_u1()
            self.conf = self._io.read_u1()
            self.uptime = self._io.read_u4le()


    class IsisEpsReplyheaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.stid = self._io.read_u1()
            self.ivid = self._io.read_u1()
            self.rc = self._io.read_u1()
            self.bid = self._io.read_u1()
            self.cmderrstat = self._io.read_u1()


    class Vec3(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.x = self._io.read_s4le()
            self.y = self._io.read_s4le()
            self.z = self._io.read_s4le()


    class ImtqCalMagfT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.cal_magf = Rhoksat.Vec3(self._io, self, self._root)
            self.coilact = self._io.read_u1()


    class IsisEpsVipdengT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.volt = self._io.read_u2le()
            self.current = self._io.read_u2le()
            self.power = self._io.read_u2le()


    class SpTelemetry(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.panel0 = Rhoksat.Panel(self._io, self, self._root)
            self.panel1 = Rhoksat.Panel(self._io, self, self._root)
            self.panel2 = Rhoksat.Panel(self._io, self, self._root)
            self.panel3 = Rhoksat.Panel(self._io, self, self._root)
            self.panel4 = Rhoksat.Panel(self._io, self, self._root)


    class EpsTelemetry(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.volt_brdsup = self._io.read_s2le()
            self.dist_input = Rhoksat.IsisEpsVipdengT(self._io, self, self._root)
            self.batt_input = Rhoksat.IsisEpsVipdengT(self._io, self, self._root)
            self.stat_obc_on = self._io.read_bits_int_be(16)
            self._io.align_to_byte()
            self.stat_obc_ocf = self._io.read_u2le()
            self.bat_stat = self._io.read_u2le()
            self.temp = self._io.read_s2le()
            self.temp2 = self._io.read_s2le()
            self.temp3 = self._io.read_s2le()
            self.status = Rhoksat.IsisEpsGetsystemstatusFromT(self._io, self, self._root)


    class Axis(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.x = self._io.read_f4le()
            self.y = self._io.read_f4le()
            self.z = self._io.read_f4le()






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if getattr(kaitaistruct, 'API_VERSION', (0, 9)) < (0, 9):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Neutron1(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field packet_type: ax25_frame.payload.ax25_info.packet_type
    :field utc: ax25_frame.payload.ax25_info.utc
    :field pos_eci_0: ax25_frame.payload.ax25_info.pos_eci_0
    :field pos_eci_1: ax25_frame.payload.ax25_info.pos_eci_1
    :field pos_eci_2: ax25_frame.payload.ax25_info.pos_eci_2
    :field vel_eci_0: ax25_frame.payload.ax25_info.vel_eci_0
    :field vel_eci_1: ax25_frame.payload.ax25_info.vel_eci_1
    :field vel_eci_2: ax25_frame.payload.ax25_info.vel_eci_2
    :field att_icrf_s_w: ax25_frame.payload.ax25_info.att_icrf_s_w
    :field att_icrf_s_x: ax25_frame.payload.ax25_info.att_icrf_s_x
    :field att_icrf_s_y: ax25_frame.payload.ax25_info.att_icrf_s_y
    :field att_icrf_s_z: ax25_frame.payload.ax25_info.att_icrf_s_z
    :field last_rssi_time: ax25_frame.payload.ax25_info.last_rssi_time
    :field batt_percent: ax25_frame.payload.ax25_info.batt_percent
    :field batt_volt: ax25_frame.payload.ax25_info.batt_volt
    :field batt_current: ax25_frame.payload.ax25_info.batt_current
    :field powgen: ax25_frame.payload.ax25_info.powgen
    :field eps_temp: ax25_frame.payload.ax25_info.eps_temp
    :field batt_temp: ax25_frame.payload.ax25_info.batt_temp
    :field cpu_temp: ax25_frame.payload.ax25_info.cpu_temp
    :field duplex_flag: ax25_frame.payload.ax25_info.duplex_flag
    :field nframes_recv_buf: ax25_frame.payload.ax25_info.nframes_recv_buf
    :field last_rssi: ax25_frame.payload.ax25_info.last_rssi
    :field antenna_deployed_status: ax25_frame.payload.ax25_info.antenna_deployed_status
    :field powmode: ax25_frame.payload.ax25_info.powmode
    :field callsign: ax25_frame.payload.ax25_info.callsign
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Neutron1.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Neutron1.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = Neutron1.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = Neutron1.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = Neutron1.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = Neutron1.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = Neutron1.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = Neutron1.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Neutron1.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Neutron1.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Neutron1.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Neutron1.SsidMask(self._io, self, self._root)
            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = Neutron1.Neutron1BeaconT(self._io, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return getattr(self, '_m_ssid', None)


    class Neutron1BeaconT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.packet_type = self._io.read_u1()
            self.utc = self._io.read_f8le()
            self.pos_eci_0 = self._io.read_f8le()
            self.pos_eci_1 = self._io.read_f8le()
            self.pos_eci_2 = self._io.read_f8le()
            self.vel_eci_0 = self._io.read_f8le()
            self.vel_eci_1 = self._io.read_f8le()
            self.vel_eci_2 = self._io.read_f8le()
            self.att_icrf_s_w = self._io.read_f8le()
            self.att_icrf_s_x = self._io.read_f8le()
            self.att_icrf_s_y = self._io.read_f8le()
            self.att_icrf_s_z = self._io.read_f8le()
            self.last_rssi_time = self._io.read_f8le()
            self.batt_percent = self._io.read_f4le()
            self.batt_volt = self._io.read_f4le()
            self.batt_current = self._io.read_f4le()
            self.powgen = self._io.read_f4le()
            self.eps_temp = self._io.read_f4le()
            self.batt_temp = self._io.read_f4le()
            self.cpu_temp = self._io.read_f4le()
            self.duplex_flag = self._io.read_u4le()
            self.nframes_recv_buf = self._io.read_u2le()
            self.last_rssi = self._io.read_u2le()
            self.antenna_deployed_status = self._io.read_u2le()
            self.powmode = self._io.read_s2le()
            self.callsign = (self._io.read_bytes(6)).decode(u"utf-8")


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Neutron1.Callsign(_io__raw_callsign_ror, self, self._root)



